@@ -64,14 +64,17 @@
 #define CFG_CONSTRAINED                 (1<<0)
 #define CFG_REQUEST                     (1<<1)
 #define CFG_NOTIFY                      (1<<2)
-#define CFG_FORCE_REDRAW                (1<<3)
+#define CFG_KEEP_VISIBLE                (1<<3)
+#define CFG_FORCE_REDRAW                (1<<4)
 
-#define INCLUDE_HIDDEN                  (1<<0)
-#define INCLUDE_SHADED                  (1<<1)
-#define INCLUDE_ALL_WORKSPACES          (1<<2)
-#define INCLUDE_SKIP_FOCUS              (1<<3)
-#define INCLUDE_SKIP_PAGER              (1<<4)
-#define INCLUDE_SKIP_TASKBAR            (1<<5)
+#define SEARCH_INCLUDE_HIDDEN           (1<<0)
+#define SEARCH_INCLUDE_SHADED           (1<<1)
+#define SEARCH_INCLUDE_ALL_WORKSPACES   (1<<2)
+#define SEARCH_INCLUDE_SKIP_FOCUS       (1<<3)
+#define SEARCH_INCLUDE_SKIP_PAGER       (1<<4)
+#define SEARCH_INCLUDE_SKIP_TASKBAR     (1<<5)
+#define SEARCH_SAME_APPLICATION         (1<<6)
+#define SEARCH_DIFFERENT_APPLICATION    (1<<7)
 
 #define NO_UPDATE_FLAG                  0
 #define UPDATE_BUTTON_GRABS             (1<<0)
@@ -190,8 +193,8 @@
                                          WINDOW_UTILITY | \
                                          WINDOW_SPLASHSCREEN)
 #define WINDOW_REGULAR_FOCUSABLE        (WINDOW_NORMAL | \
-                                         WINDOW_DIALOG | \
-                                         WINDOW_MODAL_DIALOG)
+                                         WINDOW_TYPE_DIALOG | \
+                                         WINDOW_UTILITY)
 #define WINDOW_TYPE_DONT_FOCUS          (WINDOW_SPLASHSCREEN | \
                                          WINDOW_DOCK)
 
@@ -258,6 +261,7 @@ struct _Client
     unsigned long win_state;
     unsigned long win_layer;
     unsigned long serial;
+    unsigned long initial_layer;
     Atom type_atom;
     Visual *visual;
     XSizeHints *size;
@@ -266,31 +270,30 @@ struct _Client
     Client *next;
     Client *prev;
     netWindowType type;
-    int x;
-    int y;
-    int width;
-    int height;
-    int depth;
-    int border_width;
-    int gravity;
-    int win_workspace;
+    gint x;
+    gint y;
+    gint width;
+    gint height;
+    gint depth;
+    gint border_width;
+    gint gravity;
+    guint win_workspace;
     unsigned int ignore_unmap;
-    int old_x;
-    int old_y;
-    int old_width;
-    int old_height;
-    int fullscreen_old_x;
-    int fullscreen_old_y;
-    int fullscreen_old_width;
-    int fullscreen_old_height;
-    int fullscreen_old_layer;
-    int previous_width;
-    int previous_height;
-    int initial_layer;
-    int ncmap;
-    int blink_iterations;
-    int button_status[BUTTON_COUNT];
-    int struts[STRUTS_SIZE];
+    gint old_x;
+    gint old_y;
+    gint old_width;
+    gint old_height;
+    gint fullscreen_old_x;
+    gint fullscreen_old_y;
+    gint fullscreen_old_width;
+    gint fullscreen_old_height;
+    gint fullscreen_old_layer;
+    gint previous_width;
+    gint previous_height;
+    gint ncmap;
+    gint blink_iterations;
+    gint button_status[BUTTON_COUNT];
+    gint struts[STRUTS_SIZE];
     gchar *hostname;
     gchar *name;
     guint32 user_time;
@@ -302,8 +305,8 @@ struct _Client
     gint fullscreen_monitors[4];
 
     /* Termination dialog */
-    int dialog_pid;
-    int dialog_fd;
+    gint dialog_pid;
+    gint dialog_fd;
     /* Timout for asynchronous icon update */
     guint icon_timeout_id;
     /* Timout for asynchronous frame update */
@@ -339,8 +342,6 @@ Display                 *clientGetXDisplay                      (Client *);
 void                     clientClearLastOpTime                  (Client *);
 void                     clientUpdateWinState                   (Client *,
                                                                  XClientMessageEvent *);
-void                     clientAddUserTimeWin                   (Client *);
-void                     clientRemoveUserTimeWin                (Client *);
 void                     clientUpdateUrgency                    (Client *);
 void                     clientCoordGravitate                   (Client *,
                                                                  int,
@@ -384,22 +385,23 @@ Client                  *clientGetFromWindow                    (Client *,
 void                     clientShow                             (Client *,
                                                                  gboolean);
 void                     clientWithdraw                         (Client *,
-                                                                 int,
+                                                                 guint,
                                                                  gboolean);
 void                     clientWithdrawAll                      (Client *,
-                                                                 int);
+                                                                 guint);
 void                     clientClearAllShowDesktop              (ScreenInfo *);
 void                     clientToggleShowDesktop                (ScreenInfo *);
 void                     clientActivate                         (Client *,
-                                                                 guint32);
+                                                                 guint32,
+                                                                 gboolean);
 void                     clientClose                            (Client *);
 void                     clientKill                             (Client *);
 void                     clientTerminate                        (Client *);
 void                     clientEnterContextMenuState            (Client *);
 void                     clientSetLayer                         (Client *,
-                                                                 int);
+                                                                 guint);
 void                     clientSetWorkspace                     (Client *,
-                                                                 int,
+                                                                 guint,
                                                                  gboolean);
 void                     clientShade                            (Client *);
 void                     clientUnshade                          (Client *);
@@ -432,13 +434,6 @@ void                     clientSetOpacity                       (Client *,
 void                     clientIncOpacity                       (Client *);
 void                     clientDecOpacity                       (Client *);
 void                     clientScreenResize                     (ScreenInfo *);
-void                     clientMove                             (Client *,
-                                                                 XEvent *);
-void                     clientResize                           (Client *,
-                                                                 int,
-                                                                 XEvent *);
-void                     clientCycle                            (Client *,
-                                                                 XKeyEvent *);
 void                     clientButtonPress                      (Client *,
                                                                  Window,
                                                                  XButtonEvent *);
@@ -452,8 +447,5 @@ Client                  *clientGetLeader                        (Client *);
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
 char                    *clientGetStartupId                     (Client *);
 #endif /* HAVE_LIBSTARTUP_NOTIFICATION */
-#ifdef HAVE_XSYNC
-void                     clientXSyncRequest                     (Client *);
-#endif /* HAVE_XSYNC */
 
 #endif /* INC_CLIENT_H */
